@@ -7,14 +7,13 @@
 #include <gdk/gdkpixbuf.h>
 
 #include "imgparam-window.h"
+#include "arrow-button.h"
 
 /*
  * Constants definitions
  */
 #define MAXDIRLEN 512
 #define MAXFNLEN 128
-#define MINBUTPRESSTIME 1
-#define MAXBUTPRESSDISTANCE 10
 #define MCE_SIGNAL_MATCH "type='signal'," \
 						 "sender='"    MCE_SERVICE     "'," \
 						 "path='"      MCE_SIGNAL_PATH "'," \
@@ -26,7 +25,6 @@
 /*
  * Program structure definition
  */
-typedef enum {NONE,PREVIOUS,NEXT} action_t;
 
 typedef enum {FIT_SCREEN,ONE_THIRD_RESOLUTION,HALF_RESOLUTION,FULL_RESOLUTION} zoom_t;
 
@@ -44,11 +42,9 @@ struct app_data {
 	gchar* currdir;
 	gint currfindex;
 	GList* allimgindir;
+	ArrowButton* prevarrowbut;
+	ArrowButton* nextarrowbut;
 	const gchar** rawext;
-	glong pressbuttontime;
-	gdouble pressbuttonx;
-	gdouble pressbuttony;
-	action_t actioninprog;
 	zoom_t zoomlevel;
 	gboolean showimgparam;
 };
