@@ -257,8 +257,13 @@ void store_filenames_in_dir(app_data_t *myapp) {
 			}
 			if (myapp->allimgindir != NULL) myapp->allimgindir = g_list_reverse(myapp->allimgindir);
 		}
-		if (allimages.gl_pathc <= 1) toggle_prev_next_menu_button("disable",myapp);
-		else toggle_prev_next_menu_button("enable",myapp);
+		if (allimages.gl_pathc <= 1) {
+			arrow_button_disable(myapp->prevarrowbut);
+			arrow_button_disable(myapp->nextarrowbut);
+		} else {
+			arrow_button_enable(myapp->prevarrowbut);
+			arrow_button_enable(myapp->nextarrowbut);
+		}
 		globfree(&allimages);
 		g_free(tmpstr);
 	}
