@@ -2,10 +2,9 @@
  * Functions declaration
  */
 void load_image(app_data_t *myapp,gchar *imgfname);
+void scaled_image_compute_size(app_data_t *myapp,guint *scaledwidth,guint *scaledheight);
 gboolean scale_image(GtkWidget *callerobj,app_data_t *myapp);
 void store_filenames_in_dir(app_data_t *myapp);
-gboolean draw_prev_next_arrow(app_data_t *myapp);
 void ungrab_volume_keys(GtkWidget *widget);
 void save_configuration (app_data_t *myapp);
 void load_configuration (app_data_t *myapp);
-void enable_accelerometers(app_data_t *myapp,gboolean mode);
